from django.test import TestCase
from django.urls import reverse_lazy
from django.contrib.auth import get_user_model

from .models import Species, Genus

class CladesTest(TestCase):
    @classmethod
    def setUpClass(cls):
        cls.fixture = {}
        cls.fixture['user'] = {
            'username': 'ijon_titxi',
            'email': 'ijon.titxi@stanislaw.lem',
            'password': 'solaris',
        }
        
        user = get_user_model().objects.get_or_create(
            username=cls.fixture['user']['username'],
            email=cls.fixture['user']['email']
        )[0]
        user.set_password(cls.fixture['user']['password'])
        user.save()
        super().setUpClass()

    def login(self):
        user = self.fixture['user']
        self.client.login(
            username=user['username'],
            password=user['password']
        )

class GenusTest(CladesTest):
    def test_add_genus(self):
        self.login()
        self.client.post(reverse_lazy('genus_add'),
                         data={'name': 'periparus'})
        self.assertEqual(Genus.objects.count(), 1)

    def test_absolute_url(self):
        genus_name = 'Sylvia'
        genus = Genus.objects.get_or_create(name='Sylvia')[0]
        response = self.client.get(genus.get_absolute_url())
        self.assertEqual(200, response.status_code, 'Genus has absolute_url')
        self.assertIn('id="genus"', str(response.content))
        self.assertIn(genus_name, str(response.content))


class SpeciesTest(CladesTest):
    def test_add_species(self):
        genus = Genus.objects.get_or_create(name='periparus')[0]
        self.login()
        self.client.login(username='fred', password='secret')
        
        self.client.post(reverse_lazy('species_add'),
                         data={
                             'genus': genus.pk,
                             'name': 'ater'
                         })
        self.assertEqual(Species.objects.count(), 1)
